==> qjackrcd_1.0.6~ds0.orig.tar.gz: qjackrcd-1.0.6~ds0.orig/qjackrcd_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>MainWindow</name>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Připraven</translation>
    </message>
    <message>
        <source>QJackRcd</source>
        <translation>QJackRcd</translation>
    </message>
    <message>
        <source>Split file mode</source>
        <translation>Režim rozdělení souboru</translation>
    </message>
    <message>
        <source>Auto pause</source>
        <translation>Pozastavit automaticky</translation>
    </message>
    <message>
        <source>Post processing</source>
        <translation>Další zpracování</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Krok</translation>
    </message>
    <message>
        <source>Activation delay (s)</source>
        <translation>Zpoždění spuštění (s)</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nahrávat</translation>
    </message>
    <message>
        <source>Waiting for sound...</source>
        <translation>Čeká se na zvuk...</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <source>Last file</source>
        <translation>Poslední soubor</translation>
    </message>
    <message>
        <source>Threshold (dB)</source>
        <translation>Práh (dB)</translation>
    </message>
    <message>
        <source>Recording...</source>
        <translation>Nahrává se...</translation>
    </message>
</context>
</TS>

==> qjackrcd_1.1.0~ds0.orig.tar.gz: qjackrcd-1.1.0~ds0.orig/qjackrcd_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>MainWindow</name>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Připraven</translation>
    </message>
    <message>
        <source>QJackRcd</source>
        <translation>QJackRcd</translation>
    </message>
    <message>
        <source>Split file mode</source>
        <translation>Režim rozdělení souboru</translation>
    </message>
    <message>
        <source>Auto pause</source>
        <translation>Pozastavit automaticky</translation>
    </message>
    <message>
        <source>Post processing</source>
        <translation>Další zpracování</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Krok</translation>
    </message>
    <message>
        <source>Activation delay (s)</source>
        <translation>Zpoždění spuštění (s)</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nahrávat</translation>
    </message>
    <message>
        <source>Waiting for sound...</source>
        <translation>Čeká se na zvuk...</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <source>Last file</source>
        <translation>Poslední soubor</translation>
    </message>
    <message>
        <source>Threshold (dB)</source>
        <translation>Práh (dB)</translation>
    </message>
    <message>
        <source>Recording...</source>
        <translation>Nahrává se...</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OGG</source>
        <translation>OGG</translation>
    </message>
    <message>
        <source>MP3</source>
        <translation>MP3</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable jack auto connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable jack transport</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
